summaryrefslogtreecommitdiffstats
path: root/crypto/init.c
diff options
context:
space:
mode:
authorShane Lontis <shane.lontis@oracle.com>2021-03-08 19:17:53 +1000
committerShane Lontis <shane.lontis@oracle.com>2021-03-18 17:52:37 +1000
commit1335ca4b0799d1714a2f8e21525cb23edf660e93 (patch)
tree721491aee8abff6f8e10761bc8a1f3edaf0a3eb7 /crypto/init.c
parent9500c8234d8e99396717b9e43f10cc518e8bf668 (diff)
Add ossl_rand symbols
Partial fix for #12964 Reviewed-by: Paul Dale <pauli@openssl.org> (Merged from https://github.com/openssl/openssl/pull/14473)
Diffstat (limited to 'crypto/init.c')
-rw-r--r--crypto/init.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/crypto/init.c b/crypto/init.c
index 09be58ea12..4bef667199 100644
--- a/crypto/init.c
+++ b/crypto/init.c
@@ -402,7 +402,7 @@ void OPENSSL_cleanup(void)
/*
* Note that cleanup order is important:
* - rand_cleanup_int could call an ENGINE's RAND cleanup function so
* must be called before engine_cleanup_int()
* - ENGINEs use CRYPTO_EX_DATA and therefore, must be cleaned up
* before the ex data handlers are wiped during default ossl_lib_ctx deinit.
@@ -411,8 +411,8 @@ void OPENSSL_cleanup(void)
* - ENGINEs and additional EVP algorithms might use added OIDs names so
* obj_cleanup_int() must be called last
*/
- OSSL_TRACE(INIT, "OPENSSL_cleanup: rand_cleanup_int()\n");
- rand_cleanup_int();
+ OSSL_TRACE(INIT, "OPENSSL_cleanup: ossl_rand_cleanup_int()\n");
+ ossl_rand_cleanup_int();
OSSL_TRACE(INIT, "OPENSSL_cleanup: conf_modules_free_int()\n");
conf_modules_free_int();
@@ -402,7 +402,7 @@ void OPENSSL_cleanup(void)
/*
* Note that cleanup order is important:
- * - rand_cleanup_int could call an ENGINE's RAND cleanup function so
+ * - ossl_rand_cleanup_int could call an ENGINE's RAND cleanup function so
* must be called before engine_cleanup_int()
* - ENGINEs use CRYPTO_EX_DATA and therefore, must be cleaned up